@@ -34,7 +34,19 @@
 #include "utils.h"
 #include "helpers.h"
 
-G_DEFINE_BOXED_TYPE (EAPMethod, eap_method, eap_method_ref, eap_method_unref)
+GType
+eap_method_get_type (void)
+{
+	static GType type_id = 0;
+
+	if (!type_id) {
+		type_id = g_boxed_type_register_static ("CcEAPMethod",
+							(GBoxedCopyFunc) eap_method_ref,
+							(GBoxedFreeFunc) eap_method_unref);
+	}
+
+	return type_id;
+}
 
 GtkWidget *
 eap_method_get_widget (EAPMethod *method)
@@ -54,7 +66,7 @@ eap_method_validate (EAPMethod *method, GError **error)
 	g_assert (method->validate);
 	result = (*(method->validate)) (method, error);
 	if (!result && error && !*error)
-		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("undefined error in 802.1X security (wpa-eap)"));
+		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("undefined error in 802.1x security (wpa-eap)"));
 	return result;
 }
 
@@ -155,7 +167,7 @@ eap_method_init (gsize obj_size,
 
 	method->builder = gtk_builder_new ();
 	if (!gtk_builder_add_from_resource (method->builder, ui_resource, &error)) {
-		g_warning ("Couldn't load UI builder resource %s: %s",
+		g_warning ("Couldn't load UI builder file %s: %s",
 		           ui_resource, error->message);
 		eap_method_unref (method);
 		return NULL;
@@ -270,159 +282,29 @@ out:
 	return success;
 }
 
-static gboolean
-file_has_extension (const char *filename, const char *extensions[])
-{
-	char *p, *ext;
-	int i = 0;
-	gboolean found = FALSE;
-
-	p = strrchr (filename, '.');
-	if (!p)
-		return FALSE;
-
-	ext = g_ascii_strdown (p, -1);
-	if (ext) {
-		while (extensions[i]) {
-			if (!strcmp (ext, extensions[i++])) {
-				found = TRUE;
-				break;
-			}
-		}
-	}
-	g_free (ext);
-
-	return found;
-}
-
-#if !LIBNM_BUILD
-static const char *
-find_tag (const char *tag, const char *buf, gsize len)
-{
-	gsize i, taglen;
-
-	taglen = strlen (tag);
-	if (len < taglen)
-		return NULL;
-
-	for (i = 0; i < len - taglen + 1; i++) {
-		if (memcmp (buf + i, tag, taglen) == 0)
-			return buf + i;
-	}
-	return NULL;
-}
-
-static const char *pem_rsa_key_begin = "-----BEGIN RSA PRIVATE KEY-----";
-static const char *pem_dsa_key_begin = "-----BEGIN DSA PRIVATE KEY-----";
-static const char *pem_pkcs8_enc_key_begin = "-----BEGIN ENCRYPTED PRIVATE KEY-----";
-static const char *pem_pkcs8_dec_key_begin = "-----BEGIN PRIVATE KEY-----";
-static const char *pem_cert_begin = "-----BEGIN CERTIFICATE-----";
-static const char *proc_type_tag = "Proc-Type: 4,ENCRYPTED";
-static const char *dek_info_tag = "DEK-Info:";
-
-static gboolean
-pem_file_is_encrypted (const char *buffer, gsize bytes_read)
-{
-	/* Check if the private key is encrypted or not by looking for the
-	 * old OpenSSL-style proc-type and dec-info tags.
-	 */
-	if (find_tag (proc_type_tag, (const char *) buffer, bytes_read)) {
-		if (find_tag (dek_info_tag, (const char *) buffer, bytes_read))
-			return TRUE;
-	}
-	return FALSE;
-}
-
-static gboolean
-file_is_der_or_pem (const char *filename,
-                    gboolean privkey,
-                    gboolean *out_privkey_encrypted)
-{
-	int fd;
-	unsigned char buffer[8192];
-	ssize_t bytes_read;
-	gboolean success = FALSE;
-
-	fd = open (filename, O_RDONLY);
-	if (fd < 0)
-		return FALSE;
-
-	bytes_read = read (fd, buffer, sizeof (buffer) - 1);
-	if (bytes_read < 400)  /* needs to be lower? */
-		goto out;
-	buffer[bytes_read] = '\0';
-
-	/* Check for DER signature */
-	if (bytes_read > 2 && buffer[0] == 0x30 && buffer[1] == 0x82) {
-		success = TRUE;
-		goto out;
-	}
-
-	/* Check for PEM signatures */
-	if (privkey) {
-		if (find_tag (pem_rsa_key_begin, (const char *) buffer, bytes_read)) {
-			success = TRUE;
-			if (out_privkey_encrypted)
-				*out_privkey_encrypted = pem_file_is_encrypted ((const char *) buffer, bytes_read);
-			goto out;
-		}
-
-		if (find_tag (pem_dsa_key_begin, (const char *) buffer, bytes_read)) {
-			success = TRUE;
-			if (out_privkey_encrypted)
-				*out_privkey_encrypted = pem_file_is_encrypted ((const char *) buffer, bytes_read);
-			goto out;
-		}
-
-		if (find_tag (pem_pkcs8_enc_key_begin, (const char *) buffer, bytes_read)) {
-			success = TRUE;
-			if (out_privkey_encrypted)
-				*out_privkey_encrypted = TRUE;
-			goto out;
-		}
-
-		if (find_tag (pem_pkcs8_dec_key_begin, (const char *) buffer, bytes_read)) {
-			success = TRUE;
-			if (out_privkey_encrypted)
-				*out_privkey_encrypted = FALSE;
-			goto out;
-		}
-	} else {
-		if (find_tag (pem_cert_begin, (const char *) buffer, bytes_read)) {
-			success = TRUE;
-			goto out;
-		}
-	}
-
-out:
-	close (fd);
-	return success;
-}
-#endif
-
 static gboolean
 default_filter_privkey (const GtkFileFilterInfo *filter_info, gpointer user_data)
 {
-	const char *extensions[] = { ".der", ".pem", ".p12", ".key", NULL };
+	gboolean require_encrypted = !!user_data;
+	gboolean is_encrypted;
 
 	if (!filter_info->filename)
 		return FALSE;
 
-	if (!file_has_extension (filter_info->filename, extensions))
+	is_encrypted = FALSE;
+	if (!nm_utils_file_is_private_key (filter_info->filename, &is_encrypted))
 		return FALSE;
 
-	return TRUE;
+	return require_encrypted ? is_encrypted : TRUE;
 }
 
 static gboolean
 default_filter_cert (const GtkFileFilterInfo *filter_info, gpointer user_data)
 {
-	const char *extensions[] = { ".der", ".pem", ".crt", ".cer", NULL };
-
 	if (!filter_info->filename)
 		return FALSE;
 
-	if (!file_has_extension (filter_info->filename, extensions))
+	if (!nm_utils_file_is_certificate (filter_info->filename))
 		return FALSE;
 
 	return TRUE;
@@ -448,22 +330,8 @@ gboolean
 eap_method_is_encrypted_private_key (const char *path)
 {
 	GtkFileFilterInfo info = { .filename = path };
-	gboolean is_encrypted;
 
-	if (!default_filter_privkey (&info, NULL))
-		return FALSE;
-
-#if LIBNM_BUILD
-	is_encrypted = FALSE;
-	if (!nm_utils_file_is_private_key (path, &is_encrypted))
-		return FALSE;
-#else
-	is_encrypted = TRUE;
-	if (   !file_is_der_or_pem (path, TRUE, &is_encrypted)
-	    && !nm_utils_file_is_pkcs12 (path))
-		return FALSE;
-#endif
-	return is_encrypted;
+	return default_filter_privkey (&info, (gpointer) TRUE);
 }
 
 /* Some methods (PEAP, TLS, TTLS) require a CA certificate. The user can choose
