@@ -37,7 +37,7 @@ wireless_security_get_type (void)
 	if (!type_id) {
 		g_resources_register (wireless_security_get_resource ());
 
-		type_id = g_boxed_type_register_static ("WirelessSecurity",
+		type_id = g_boxed_type_register_static ("CcWirelessSecurity",
 							(GBoxedCopyFunc) wireless_security_ref,
 							(GBoxedFreeFunc) wireless_security_unref);
 	}
@@ -84,7 +84,7 @@ wireless_security_validate (WirelessSecurity *sec, GError **error)
 	g_assert (sec->validate);
 	result = (*(sec->validate)) (sec, error);
 	if (!result && error && !*error)
-		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Unknown error validating 802.1X security"));
+		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Unknown error validating 802.1x security"));
 	return result;
 }
 
@@ -186,7 +186,7 @@ wireless_security_init (gsize obj_size,
 
 	sec->builder = gtk_builder_new ();
 	if (!gtk_builder_add_from_resource (sec->builder, ui_resource, &error)) {
-		g_warning ("Couldn't load UI builder resource %s: %s",
+		g_warning ("Couldn't load UI builder file %s: %s",
 		           ui_resource, error->message);
 		g_error_free (error);
 		wireless_security_unref (sec);
@@ -551,7 +551,7 @@ ws_802_1x_fill_connection (WirelessSecurity *sec,
 	gtk_tree_model_get (model, &iter, AUTH_METHOD_COLUMN, &eap, -1);
 	g_assert (eap);
 
-	/* Get previous pasword flags, if any. Otherwise default to agent-owned secrets */
+	/* Get previous password flags, if any. Otherwise default to agent-owned secrets */
 	s_8021x = nm_connection_get_setting_802_1x (connection);
 	if (s_8021x)
 		nm_setting_get_secret_flags (NM_SETTING (s_8021x), eap->password_flags_name, &secret_flags, NULL);
