@@ -19,6 +19,7 @@
  * Author: Thomas Wood <thos@gnome.org>
  */
 
+#include "config.h"
 
 #include "cinnamon-control-center.h"
 
@@ -178,7 +179,7 @@ get_icon_name_from_g_icon (GIcon *gicon)
 static gboolean
 activate_panel (CinnamonControlCenter *shell,
                 const gchar        *id,
-		const gchar       **argv,
+                GVariant           *parameters,
                 const gchar        *desktop_file,
                 const gchar        *name,
                 GIcon              *gicon)
@@ -236,7 +237,7 @@ activate_panel (CinnamonControlCenter *shell,
     }
 
   /* create the panel plugin */
-  priv->current_panel = g_object_new (panel_type, "shell", shell, "argv", argv, NULL);
+  priv->current_panel = g_object_new (panel_type, "shell", shell, "parameters", parameters, NULL);
   cc_shell_set_active_panel (CC_SHELL (shell), CC_PANEL (priv->current_panel));
   gtk_widget_show (priv->current_panel);
 
@@ -791,56 +792,39 @@ static void
 reload_menu (CinnamonControlCenter *shell)
 {
   GError *error;
-  GMenuTreeDirectory *d;
-  GMenuTreeIter *iter;
-  GMenuTreeItemType next_type;
+  GDir *dir;
+  const gchar *name;
 
   error = NULL;
-  if (!gmenu_tree_load_sync (shell->priv->menu_tree, &error))
+
+  maybe_add_category_view (shell, "C Modules");
+
+  dir = g_dir_open (PANEL_DEF_DIR, 0, &error);
+
+  if (error != NULL)
     {
-      g_warning ("Could not load control center menu: %s", error->message);
-      g_clear_error (&error);
+      g_critical ("Could not read PANEL_DEF_DIR: %s", PANEL_DEF_DIR);
+      g_error_free (error);
       return;
     }
 
-
-  d = gmenu_tree_get_root_directory (shell->priv->menu_tree);
-  iter = gmenu_tree_directory_iter (d);
-
-  while ((next_type = gmenu_tree_iter_next (iter)) != GMENU_TREE_ITEM_INVALID)
+  do
     {
-      if (next_type == GMENU_TREE_ITEM_DIRECTORY)
+      gchar *full_path;
+      name = g_dir_read_name (dir);
+
+      if (name == NULL)
         {
-          GMenuTreeDirectory *subdir;
-          const gchar *dir_name;
-          GMenuTreeIter *sub_iter;
-          GMenuTreeItemType sub_next_type;
-
-          subdir = gmenu_tree_iter_get_directory (iter);
-          dir_name = gmenu_tree_directory_get_name (subdir);
-
-          maybe_add_category_view (shell, dir_name);
-
-          /* add the items from this category to the model */
-          sub_iter = gmenu_tree_directory_iter (subdir);
-          while ((sub_next_type = gmenu_tree_iter_next (sub_iter)) != GMENU_TREE_ITEM_INVALID)
-            {
-              if (sub_next_type == GMENU_TREE_ITEM_ENTRY)
-                {
-                  GMenuTreeEntry *item = gmenu_tree_iter_get_entry (sub_iter);
-                  cc_shell_model_add_item (CC_SHELL_MODEL (shell->priv->store),
-                                           dir_name,
-                                           item);
-                  gmenu_tree_item_unref (item);
-                }
-            }
-
-          gmenu_tree_iter_unref (sub_iter);
-          gmenu_tree_item_unref (subdir);
+          break;
         }
-    }
 
-  gmenu_tree_iter_unref (iter);
+      full_path = g_build_filename (PANEL_DEF_DIR, name, NULL);
+      cc_shell_model_add_item (CC_SHELL_MODEL (shell->priv->store), full_path);
+
+      g_free (full_path);
+    } while (name != NULL);
+
+    g_dir_close (dir);
 }
 
 static void
@@ -967,7 +951,7 @@ _shell_embed_widget_in_header (CcShell      *shell,
 static gboolean
 _shell_set_active_panel_from_id (CcShell      *shell,
                                  const gchar  *start_id,
-				 const gchar **argv,
+                                 GVariant     *parameters,
                                  GError      **err)
 {
   GtkTreeIter iter;
@@ -978,10 +962,10 @@ _shell_set_active_panel_from_id (CcShell      *shell,
   CinnamonControlCenterPrivate *priv = CINNAMON_CONTROL_CENTER (shell)->priv;
   GtkWidget *old_panel;
 
-  /* When loading the same panel again, just set the argv */
+  /* When loading the same panel again, just set its parameters */
   if (g_strcmp0 (priv->current_panel_id, start_id) == 0)
     {
-      g_object_set (G_OBJECT (priv->current_panel), "argv", argv, NULL);
+      g_object_set (G_OBJECT (priv->current_panel), "parameters", parameters, NULL);
       return TRUE;
     }
 
@@ -1035,7 +1019,7 @@ _shell_set_active_panel_from_id (CcShell      *shell,
     {
       g_warning ("Could not find settings panel \"%s\"", start_id);
     }
-  else if (activate_panel (CINNAMON_CONTROL_CENTER (shell), start_id, argv, desktop,
+  else if (activate_panel (CINNAMON_CONTROL_CENTER (shell), start_id, parameters, desktop,
                            name, gicon) == FALSE)
     {
       /* Failed to activate the panel for some reason */
